![](https://github.com/phuang1024/pianoray/actions/workflows/ci.yml/badge.svg)
![](https://img.shields.io/github/issues/phuang1024/pianoray)
![](https://img.shields.io/github/issues-pr/phuang1024/pianoray)
![](https://img.shields.io/github/license/phuang1024/pianoray)
![](https://img.shields.io/github/v/release/phuang1024/pianoray)
![](https://img.shields.io/tokei/lines/github/phuang1024/pianoray)
![](https://img.shields.io/github/repo-size/phuang1024/pianoray)

# PianoRay

Piano performance visualizer.

![](https://github.com/phuang1024/pianoray/blob/master/examples/renders/furelise.jpg?raw=true)
